@@ -13,9 +13,6 @@ char *totem_time_to_string (gint64 msecs);
 gint64 totem_string_to_time (const char *time_string);
 char *totem_time_to_string_text (gint64 msecs);
 
-void totem_widget_set_preferred_size (GtkWidget *widget,
-				      gint width,
-				      gint height);
 gboolean totem_ratio_fits_screen (GtkWidget *widget,
 				  int video_width,
 				  int video_height,
