@@ -36,41 +36,27 @@
 #include <libpeas/peas-activatable.h>
 
 #include "totem-plugin.h"
-#include "totem-skipto-plugin.h"
 #include "totem-skipto.h"
 
-struct TotemSkiptoPluginPrivate
-{
+#define TOTEM_TYPE_SKIPTO_PLUGIN		(totem_skipto_plugin_get_type ())
+#define TOTEM_SKIPTO_PLUGIN(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), TOTEM_TYPE_SKIPTO_PLUGIN, TotemSkiptoPlugin))
+#define TOTEM_SKIPTO_PLUGIN_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), TOTEM_TYPE_SKIPTO_PLUGIN, TotemSkiptoPluginClass))
+#define TOTEM_IS_SKIPTO_PLUGIN(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), TOTEM_TYPE_SKIPTO_PLUGIN))
+#define TOTEM_IS_SKIPTO_PLUGIN_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_SKIPTO_PLUGIN))
+#define TOTEM_SKIPTO_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_SKIPTO_PLUGIN, TotemSkiptoPluginClass))
+
+typedef struct {
+	TotemObject	*totem;
 	TotemSkipto	*st;
 	guint		handler_id_stream_length;
 	guint		handler_id_seekable;
 	guint		handler_id_key_press;
 	guint		ui_merge_id;
 	GtkActionGroup	*action_group;
-};
-
-static void totem_skipto_plugin_finalize (GObject *object);
+} TotemSkiptoPluginPrivate;
 
 TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_SKIPTO_PLUGIN, TotemSkiptoPlugin, totem_skipto_plugin)
 
-static void
-totem_skipto_plugin_class_init (TotemSkiptoPluginClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-	g_type_class_add_private (klass, sizeof (TotemSkiptoPluginPrivate));
-
-	object_class->finalize = totem_skipto_plugin_finalize;
-}
-static void
-totem_skipto_plugin_init (TotemSkiptoPlugin *plugin)
-{
-	plugin->priv = G_TYPE_INSTANCE_GET_PRIVATE (plugin,
-						    TOTEM_TYPE_SKIPTO_PLUGIN,
-						    TotemSkiptoPluginPrivate);
-	plugin->priv->st = NULL;
-}
-
 static void
 destroy_dialog (TotemSkiptoPlugin *plugin)
 {
@@ -84,16 +70,6 @@ destroy_dialog (TotemSkiptoPlugin *plugin)
 	}
 }
 
-static void
-totem_skipto_plugin_finalize (GObject *object)
-{
-	TotemSkiptoPlugin *plugin = TOTEM_SKIPTO_PLUGIN (object);
-
-	destroy_dialog (plugin);
-
-	G_OBJECT_CLASS (totem_skipto_plugin_parent_class)->finalize (object);
-}
-
 static void
 totem_skipto_update_from_state (TotemObject *totem,
 				TotemSkiptoPlugin *plugin)
@@ -136,7 +112,7 @@ skip_to_response_callback (GtkDialog *dialog, gint response, TotemSkiptoPlugin *
 
 	gtk_widget_hide (GTK_WIDGET (dialog));
 
-	totem_action_seek_time (plugin->totem,
+	totem_action_seek_time (plugin->priv->totem,
 				totem_skipto_get_range (plugin->priv->st),
 				TRUE);
 	destroy_dialog (plugin);
@@ -147,26 +123,26 @@ run_skip_to_dialog (TotemSkiptoPlugin *plugin)
 {
 	TotemSkiptoPluginPrivate *priv = plugin->priv;
 
-	if (totem_is_seekable (plugin->totem) == FALSE)
+	if (totem_is_seekable (priv->totem) == FALSE)
 		return;
 
 	if (priv->st != NULL) {
 		gtk_window_present (GTK_WINDOW (priv->st));
 		totem_skipto_set_current (priv->st, totem_get_current_time
-					  (plugin->totem));
+					  (priv->totem));
 		return;
 	}
 
-	priv->st = TOTEM_SKIPTO (totem_skipto_new (plugin));
+	priv->st = TOTEM_SKIPTO (totem_skipto_new (priv->totem));
 	g_signal_connect (G_OBJECT (priv->st), "delete-event",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
 	g_signal_connect (G_OBJECT (priv->st), "response",
 			  G_CALLBACK (skip_to_response_callback), plugin);
 	g_object_add_weak_pointer (G_OBJECT (priv->st),
 				   (gpointer *)&(priv->st));
-	totem_skipto_update_from_state (plugin->totem, plugin);
+	totem_skipto_update_from_state (priv->totem, plugin);
 	totem_skipto_set_current (priv->st,
-				  totem_get_current_time (plugin->totem));
+				  totem_get_current_time (priv->totem));
 }
 
 static void
@@ -183,8 +159,8 @@ on_window_key_press_event (GtkWidget *window, GdkEventKey *event, TotemSkiptoPlu
 		return FALSE;
 
 	switch (event->keyval) {
-		case GDK_k:
-		case GDK_K:
+		case GDK_KEY_k:
+		case GDK_KEY_K:
 			run_skip_to_dialog (plugin);
 			break;
 		default:
@@ -195,31 +171,29 @@ on_window_key_press_event (GtkWidget *window, GdkEventKey *event, TotemSkiptoPlu
 }
 
 static void
-impl_activate (PeasActivatable *plugin,
-	       GObject *object)
+impl_activate (PeasActivatable *plugin)
 {
 	GtkWindow *window;
 	GtkUIManager *manager;
 	TotemSkiptoPlugin *pi = TOTEM_SKIPTO_PLUGIN (plugin);
 	TotemSkiptoPluginPrivate *priv = pi->priv;
-	TotemObject *totem = TOTEM_OBJECT (object);
 
 	const GtkActionEntry menu_entries[] = {
 		{ "skip-to", GTK_STOCK_JUMP_TO, N_("_Skip to..."), "<Control>K", N_("Skip to a specific time"), G_CALLBACK (skip_to_action_callback) }
 	};
 
-	pi->totem = totem;
-	priv->handler_id_stream_length = g_signal_connect (G_OBJECT (totem),
+	priv->totem = g_object_get_data (G_OBJECT (plugin), "object");
+	priv->handler_id_stream_length = g_signal_connect (G_OBJECT (priv->totem),
 				"notify::stream-length",
 				G_CALLBACK (property_notify_cb),
 				pi);
-	priv->handler_id_seekable = g_signal_connect (G_OBJECT (totem),
+	priv->handler_id_seekable = g_signal_connect (G_OBJECT (priv->totem),
 				"notify::seekable",
 				G_CALLBACK (property_notify_cb),
 				pi);
 
 	/* Key press handler */
-	window = totem_get_main_window (totem);
+	window = totem_get_main_window (priv->totem);
 	priv->handler_id_key_press = g_signal_connect (G_OBJECT(window),
 				"key-press-event",
 				G_CALLBACK (on_window_key_press_event),
@@ -232,7 +206,7 @@ impl_activate (PeasActivatable *plugin,
 	gtk_action_group_add_actions (priv->action_group, menu_entries,
 				G_N_ELEMENTS (menu_entries), pi);
 
-	manager = totem_get_ui_manager (totem);
+	manager = totem_get_ui_manager (priv->totem);
 
 	gtk_ui_manager_insert_action_group (manager, priv->action_group, -1);
 	g_object_unref (priv->action_group);
@@ -242,18 +216,19 @@ impl_activate (PeasActivatable *plugin,
 			       "/ui/tmw-menubar/go/skip-forward", "skip-to",
 			       "skip-to", GTK_UI_MANAGER_AUTO, TRUE);
 
-	totem_skipto_update_from_state (totem, pi);
+	totem_skipto_update_from_state (priv->totem, pi);
 }
 
 static void
-impl_deactivate	(PeasActivatable *plugin,
-		 GObject *object)
+impl_deactivate (PeasActivatable *plugin)
 {
 	GtkWindow *window;
 	GtkUIManager *manager;
-	TotemObject *totem = TOTEM_OBJECT (object);
+	TotemObject *totem;
 	TotemSkiptoPluginPrivate *priv = TOTEM_SKIPTO_PLUGIN (plugin)->priv;
 
+	totem = g_object_get_data (G_OBJECT (plugin), "object");
+
 	g_signal_handler_disconnect (G_OBJECT (totem),
 				     priv->handler_id_stream_length);
 	g_signal_handler_disconnect (G_OBJECT (totem),
@@ -271,5 +246,7 @@ impl_deactivate	(PeasActivatable *plugin,
 	manager = totem_get_ui_manager (totem);
 	gtk_ui_manager_remove_ui (manager, priv->ui_merge_id);
 	gtk_ui_manager_remove_action_group (manager, priv->action_group);
+
+	destroy_dialog (TOTEM_SKIPTO_PLUGIN (plugin));
 }
 
