@@ -46,54 +46,34 @@
 #define TOTEM_IS_TRACKER_PLUGIN_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), TOTEM_TYPE_TRACKER_PLUGIN))
 #define TOTEM_TRACKER_PLUGIN_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), TOTEM_TYPE_TRACKER_PLUGIN, TotemTrackerPluginClass))
 
-typedef struct
-{
-	TotemPlugin   parent;
-} TotemTrackerPlugin;
+typedef struct {
+	gpointer unused;
+} TotemTrackerPluginPrivate;
 
-typedef struct
-{
-	TotemPluginClass parent_class;
-} TotemTrackerPluginClass;
-
-
-G_MODULE_EXPORT GType register_totem_plugin		(GTypeModule *module);
-GType	totem_tracker_plugin_get_type			(void) G_GNUC_CONST;
-
-static void impl_activate				(TotemPlugin *plugin, TotemObject *totem);
-static void impl_deactivate				(TotemPlugin *plugin, TotemObject *totem);
-
-TOTEM_PLUGIN_REGISTER (TotemTrackerPlugin, totem_tracker_plugin)
+TOTEM_PLUGIN_REGISTER (TOTEM_TYPE_TRACKER_PLUGIN, TotemTrackerPlugin, totem_tracker_plugin);
 
 static void
-totem_tracker_plugin_class_init (TotemTrackerPluginClass *klass)
-{
-	PeasPluginClass *plugin_class = PEAS_PLUGIN_CLASS (klass);
-
-	plugin_class->activate = (PeasFunc) impl_activate;
-	plugin_class->deactivate = (PeasFunc) impl_deactivate;
-}
-
-static void
-totem_tracker_plugin_init (TotemTrackerPlugin *plugin)
-{
-}
-
-static void
-impl_activate (TotemPlugin *plugin,
-	       TotemObject *totem)
+impl_activate (PeasActivatable *plugin)
 {
 	GtkWidget *widget;
+	TotemObject *totem;
+
+	g_object_get (plugin, "object", &totem, NULL);
 
 	widget = totem_tracker_widget_new (totem);
 	gtk_widget_show (widget);
 	totem_add_sidebar_page (totem, "tracker", _("Local Search"), widget);
+
+	g_object_unref (totem);
 }
 
 static void
-impl_deactivate	(TotemPlugin *plugin,
-		 TotemObject *totem)
+impl_deactivate (PeasActivatable *plugin)
 {
+	TotemObject *totem;
+
+	g_object_get (plugin, "object", &totem, NULL);
 	totem_remove_sidebar_page (totem, "tracker");
+	g_object_unref (totem);
 }
 
