@@ -26,7 +26,7 @@
 #include <glib/gi18n.h>
 #include <gst/tag/tag.h>
 #include <string.h>
-#include <libpeasui/peas-ui-plugin-manager.h>
+#include <libpeas-gtk/peas-gtk-plugin-manager.h>
 
 #include "totem-menu.h"
 #include "totem.h"
@@ -188,11 +188,13 @@ create_lang_actions (Totem *totem, GtkActionGroup *action_group, guint ui_id,
 
 	if (is_lang == FALSE) {
 		add_lang_action (totem, action_group, ui_id, paths, prefix,
+		                /* Translators: an entry in the "Languages" menu, used to choose the audio language of a DVD */
 				_("None"), -2, 0, &group);
 	}
 
 	action = add_lang_action (totem, action_group, ui_id, paths, prefix,
-			_("Auto"), -1, 0, &group);
+	                          /* Translators: an entry in the "Languages" menu, used to choose the audio language of a DVD */
+	                          C_("Language", "Auto"), -1, 0, &group);
 
 	i = 0;
 	lookup = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
@@ -1223,7 +1225,6 @@ plugins_action_callback (GtkAction *action, Totem *totem)
 							      NULL);
 		gtk_container_set_border_width (GTK_CONTAINER (totem->plugins), 5);
 		gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (totem->plugins))), 2);
-		gtk_dialog_set_has_separator (GTK_DIALOG (totem->plugins), FALSE);
 
 		g_signal_connect_object (G_OBJECT (totem->plugins),
 					 "delete_event",
@@ -1234,7 +1235,7 @@ plugins_action_callback (GtkAction *action, Totem *totem)
 					 G_CALLBACK (totem_plugins_response_cb),
 					 NULL, 0);
 
-		manager = peas_ui_plugin_manager_new (PEAS_ENGINE (totem->engine));
+		manager = peas_gtk_plugin_manager_new ();
 		gtk_widget_show_all (GTK_WIDGET (manager));
 		gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (totem->plugins))),
 				   manager);
